@@ -1154,7 +1154,7 @@ class AlchemyCacheStorage(object):
             response: scrapy.http.Response,
             cached_pages: List[CachedResponseBody]
     ):
-        timestamp = datetime.datetime.now()
+        timestamp = datetime.datetime.now(datetime.timezone.utc)
         cached_html = self.reconstruct_html(cached_pages)
         has_changed = cached_html != response.text
 
@@ -1290,7 +1290,8 @@ class AlchemyCacheStorage(object):
         if not scrape_timestamp:
             return None
 
-        time_diff = (datetime.datetime.now() - scrape_timestamp).total_seconds()
+        now = datetime.datetime.now(datetime.timezone.utc)
+        time_diff = (now - scrape_timestamp).total_seconds()
 
         # If the item isn't found in the cache or it's been too long since
         # we've scraped the page, then don't use the cached item.
