@@ -619,7 +619,7 @@ class TestAlchemyCacheStorage(unittest.TestCase):
         self.assertEqual(act_response_2.text, response2.text)
 
         # Get the current time
-        current_time = datetime.datetime.now()
+        current_time = datetime.datetime.now(datetime.timezone.utc)
 
         # Now store the response again. The retrieved scrape_timestamp should
         # be after the current time.
